@@ -8,12 +8,13 @@ from google.api_core import retry
 
 import octue.exceptions
 import twined.exceptions
+from octue.definitions import GOOGLE_COMPUTE_PROVIDERS
 from octue.log_handlers import COLOUR_PALETTE
 from octue.resources.manifest import Manifest
 from octue.utils.exceptions import create_exceptions_mapping
 
 
-if os.environ.get("COMPUTE_PROVIDER", "UNKNOWN") in {"GOOGLE_CLOUD_RUN", "GOOGLE_DATAFLOW"}:
+if os.environ.get("COMPUTE_PROVIDER", "UNKNOWN") in GOOGLE_COMPUTE_PROVIDERS:
     # Google Cloud logs don't support colour currently - provide a no-operation function.
     colourise = lambda string, text_colour=None, background_colour=None: string
 else:
@@ -217,7 +218,7 @@ class OrderedMessageHandler:
         # Colour any analysis sections from children of the immediate child with the rest of the colour palette and
         # colour the message from the furthest child white.
         subchild_analysis_sections = [section.strip("[") for section in re.split("] ", record.msg)]
-        final_message = colourise(subchild_analysis_sections.pop(-1))
+        final_message = subchild_analysis_sections.pop(-1)
 
         for i in range(len(subchild_analysis_sections)):
             subchild_analysis_sections[i] = colourise(
