@@ -25,32 +25,35 @@ CLASS_MAP = {"configuration_manifest": Manifest, "input_manifest": Manifest, "ou
 
 
 class Analysis(Identifiable, Serialisable, Labelable, Taggable):
-    """A class representing a scientific or computational analysis, holding references to all configuration, input, and
-    output data.
+    """A class representing a scientific or computational analysis. It holds references to all configuration, input, and
+    output data, logs, connections to child services, credentials, etc. It's essentially the "Internal API" for your
+    service - a single point of contact where you can get or update anything you need.
 
-    An Analysis instance is unique to a specific computational analysis task, however large or small, run at a specific
-    time. It will be created by the task runner, which will have validated incoming data already (Analysis doesn't
-    do any validation).
+    An ``Analysis`` instance is automatically provided to the app in an Octue service when a question is received. Its
+    attributes include every strand that can be added to a ``Twine``, although only the strands specified in the
+    service's twine will be non-``None``. Incoming data is validated before it's added to the analysis.
 
-    It holds references to all configuration, input, and output data, logs, connections to child twins, credentials,
-    etc, so should be referred to from your code to get those items.
+    All input and configuration attributes are hashed using a `BLAKE3 hash <https://github.com/BLAKE3-team/BLAKE3>`_ so
+    the inputs and configuration that produced a given output in your app can always be verified. These hashes exist on
+    the following attributes:
 
-    It's basically the "Internal API" for your data service - a single point of contact where you can get or update
-    anything you need.
+    -   ``input_values_hash``
+    -   ``input_manifest_hash``
+    -   ``configuration_values_hash``
+    -   ``configuration_manifest_hash``
 
-    Analyses are instantiated at the top level of your app/service/twin code and you can import the instantiated
-    object from there (see the templates for examples)
+    If a strand is ``None``, so will its corresponding hash attribute be. The hash of a datafile is the hash of its
+    file, while the hash of a manifest or dataset is the cumulative hash of the files it refers to.
 
-    :param twined.Twine|str|dict twine: Twine instance or json source
-    :param callable|None handle_monitor_message: a function that sends monitor messages to the parent that requested the analysis
-    :param any configuration_values: see Runner.run() for definition
-    :param octue.resources.manifest.Manifest configuration_manifest: see Runner.run() for definition
-    :param any input_values: see Runner.run() for definition
-    :param octue.resources.manifest.Manifest input_manifest: see Runner.run() for definition
-    :param dict credentials: see Runner.run() for definition
-    :param dict monitors: see Runner.run() for definition
-    :param any output_values: see Runner.run() for definition
-    :param octue.resources.manifest.Manifest output_manifest: see Runner.run() for definition
+    :param twined.Twine|dict|str twine: the twine, dictionary defining a twine, or path to "twine.json" file defining the service's data interface
+    :param callable|None handle_monitor_message: an optional function for sending monitor messages to the parent that requested the analysis
+    :param any configuration_values: the configuration values for the analysis - this can be expressed as a python primitive (e.g. dict), a path to a JSON file, or a JSON string.
+    :param octue.resources.manifest.Manifest configuration_manifest: a manifest of configuration datasets for the analysis if required
+    :param any input_values: the input values for the analysis - this can be expressed as a python primitive (e.g. dict), a path to a JSON file, or a JSON string.
+    :param octue.resources.manifest.Manifest input_manifest: a manifest of input datasets for the analysis if required
+    :param any output_values: any output values the analysis produces
+    :param octue.resources.manifest.Manifest output_manifest: a manifest of output dataset from the analysis if it produces any
+    :param dict children: a mapping of string key to ``Child`` instance for all the children used by the service
     :param str id: Optional UUID for the analysis
     :return None:
     """
@@ -66,8 +69,8 @@ class Analysis(Identifiable, Serialisable, Labelable, Taggable):
         strand_kwargs = {name: kwargs.pop(name, None) for name in ALL_STRANDS}
 
         # Values strands.
-        self.input_values = strand_kwargs.get("input_values", None)
         self.configuration_values = strand_kwargs.get("configuration_values", None)
+        self.input_values = strand_kwargs.get("input_values", None)
         self.output_values = strand_kwargs.get("output_values", None)
 
         # Manifest strands.
@@ -76,14 +79,12 @@ class Analysis(Identifiable, Serialisable, Labelable, Taggable):
         self.output_manifest = strand_kwargs.get("output_manifest", None)
 
         # Other strands.
-        self.credentials = strand_kwargs.get("credentials", None)
         self.children = strand_kwargs.get("children", None)
-        self.monitors = strand_kwargs.get("monitors", None)
 
+        # Non-strands.
         self.output_location = kwargs.pop("output_location", None)
 
         self._calculate_strand_hashes(strands=strand_kwargs)
-
         super().__init__(**kwargs)
 
     def send_monitor_message(self, data):
